import { h } from "@stencil/core";
import { ACreateMessage } from "./base";
const fileTypeMap = {
  'application/zip': 'file-zip',
  'application/gzip': 'file-zip',
  'application/x-zip-compressed': 'file-zip',
  'application/x-tar': 'file-zip',
  'application/x-compressed': 'file-zip',
  'application/msword': 'file-word',
  'application/vnd.openxmlformats-officedocument.wordprocessingml.document': 'file-word',
  'application/rtf': 'file-text',
  'application/vnd.ms-excel application/x-excel': 'file-xls',
  'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet': 'file-xls',
  'application/x-xls': 'file-xls',
  'text/csv': 'file-xls',
  'application/vnd.ms-excel': 'file-xls',
  'application/x-ppt': 'file-ppt',
  'application/vnd.ms-powerpoint': 'file-ppt',
  'application/vnd.openxmlformats-officedocument.presentationml.presentation': 'file-ppt',
  'application/vnd.openxmlformats-officedocument.presentationml.slideshow': 'file-ppt',
  'application/pdf': 'file-pdf',
  'audio/mp3': 'file-audio',
  'audio/wav': 'file-audio',
  'audio/m3u': 'file-audio',
  'audio/midi': 'file-audio',
  'audio/flac': 'file-audio',
  'audio/ape': 'file-audio',
  'audio/x-ms-wma': 'file-audio',
  'video/mpeg4': 'file-video',
  'video/x-ms-wmv': 'file-video',
  'video/avi': 'file-video',
  'video/mpg': 'file-video',
  'video/mp4': 'file-video',
  'video/x-msvideo': 'file-video',
  'video/x-flv': 'file-video',
  'application/x-mpegURL': 'file-video',
  'video/3gpp': 'file-video',
  'text/plain': 'file-plain',
  'image/jpeg': 'file-image',
  'image/tiff': 'file-image',
  'image/png': 'file-image',
  'image/gif': 'file-image',
  'application/vnd.android.package-archive': 'file-apk',
  'application/xml': 'file-text',
  'application/rdf+xml': 'file-text',
  'application/rss+xml': 'file-text',
  'application/soap+xml': 'file-text',
  'application/atom+xml': 'file-text',
  'application/xhtml+xml': 'file-text',
  'text/html': 'file-text',
  'text/xml': 'file-text',
  'text/css': 'file-text'
};
/**
 * 格式化文件大小为适合查看的单位
 * @param size 单位字节
 * @returns
 */
function formatSize(size) {
  if (size < 1024) {
    return size + 'B';
  }
  else if (size > 1024 * 1024 * 1024) {
    size = (size / 1024 / 1024 / 1024).toFixed(2) + 'G';
  }
  else if (size > 1024 * 1024) {
    size = (size / 1024 / 1024).toFixed(2) + 'M';
  }
  else if (size > 1024) {
    size = (size / 1024).toFixed(2) + 'K';
  }
  return size;
}
export default class FileMessage extends ACreateMessage {
  constructor(message, callback) {
    super(message, callback);
    this.handleClick = this.handleClick.bind(this);
  }
  handleClick() {
    if (typeof this.callback === 'function') {
      this.callback({
        type: 'file',
        url: this.content.fileUrl,
        size: this.content.size,
        name: this.content.name,
        fileType: this.content.type
      });
    }
  }
  getFileIcon(type, name) {
    const fileType = fileTypeMap[type];
    if (!fileType) {
      console.log('暂未识别的文件类型：' + type, name);
    }
    return fileType || 'file-icon';
  }
  create() {
    const content = this.content;
    return this.wrap(h("div", { class: "file-message-body", "data-origin": content.imageUri },
      h("div", { class: 'file-message-icon ' + this.getFileIcon(content.type, content.name) }),
      h("div", { class: "file-desc" },
        h("div", { class: "file-name", title: content.name }, content.name),
        h("div", { class: "file-size" }, formatSize(content.size))),
      (this.uid.startsWith('sending_') || this.uid.startsWith('fail_')) ? null :
        h("div", { class: "file-download-btn", onClick: this.handleClick })));
  }
}
