import { login, logout, getInfo } from "@/api/user";
import {
  getToken,
  setToken,
  removeToken,
  removeCrossToken,
  setCrossToken,
  removeTenant
} from "@/utils/auth";
import { tenantInfoQueryPage, tenantInfoInfo } from "@/views/organManager/api";
import { resetRouter } from "@/router";
import { setTheme } from "@/utils/setTheme";
// import qs from 'qs'
const state = {
  token: getToken(),
  name: "",
  avatar: "",
  positionName: "", // 职位
  organ: "",
  organName: "",
  phone: "",
  isSuperAdmin: false,
  roles: [],
  tenantId: null,
  baseTenantId: null,
  imToken: ""
};

let stateTenantId = null; // 机构编号
// organName
const mutations = {
  SET_TOKEN: (state, token) => {
    state.token = token;
  },
  SET_NAME: (state, name) => {
    state.name = name;
  },
  SET_AVATAR: (state, avatar) => {
    state.avatar = avatar;
  },
  SET_ORGAN: (state, organ) => {
    state.organ = organ;
  },
  SET_ORGANNAME: (state, organName) => {
    state.organName = organName;
  },
  SET_REFRESH_TOKEN: (state, refreshToken) => {
    state.refreshToken = refreshToken;
  },
  SET_EXPIRES_IN: (state, expiresIn) => {
    state.expiresIn = expiresIn;
  },
  SET_PHONE: (state, phone) => {
    state.phone = phone;
  },
  SET_SUPERADMIN: (state, isSuperAdmin) => {
    state.isSuperAdmin = isSuperAdmin;
  },
  SET_ROLES: (state, roles) => {
    state.roles = roles;
  },
  SET_TENANTID: (state, tenantId) => {
    state.tenantId = tenantId;
  },
  SET_POSITIONNAME: (state, positionName) => {
    state.positionName = positionName;
  },
  SET_BASETENANTID: (state, baseTenantId) => {
    state.baseTenantId = baseTenantId;
  },
  SET_IMTOKEN: (state, imToken) => {
    state.imToken = imToken;
  }
};

async function tenantQueryPage(id) {
  try {
    let tenantId = id;
    if (tenantId < 0) {
      const res = await tenantInfoQueryPage({
        page: 1,
        rows: 1,
        payState: 1,
        state: 1
      });
      const tenantList = res.data?.rows || [];
      tenantId = tenantList[0]?.id;
    }
    stateTenantId = tenantId;
    if (tenantId) {
      const info = await tenantInfoInfo({ id: tenantId });
      const data = info.data;
      stateTenantId = data.id;
      sessionStorage.setItem(
        "tenantConfig",
        JSON.stringify({
          themeColor: data.config.themeColor,
          theme: data.config.theme,
          tenantId: data.id,
          tenantName: data.name,
          tenantLogo: data.logo,
          tenantStatus: "on" // 判断是否此状态，没有的话，刷新页面会重新请求页面
        })
      );
    }
  } catch (e) {}
}

const actions = {
  setUserName({ commit }, userName) {
    commit("SET_NAME", userName);
  },
  setUserAvatar({ commit }, userName) {
    commit("SET_AVATAR", userName);
  },
  // user login
  async login({ commit }, userInfo) {
    const { username, password } = userInfo;
    return await new Promise((resolve, reject) => {
      //qs.stringify({ username: username.trim(), password: password, clientId: 'app', clientSecret: 'app' })
      // { username: username.trim(), password: password }
      login({
        username: username.trim(),
        password: password,
        clientId: "system",
        clientSecret: "system"
      })
        .then(response => {
          const { data } = response;
          if (response.code == 200) {
            let token =
              data.authentication.token_type +
              " " +
              data.authentication.access_token;
            commit("SET_REFRESH_TOKEN", data.authentication.refresh_token);
            commit("SET_EXPIRES_IN", data.authentication.expires_in);
            commit("SET_TOKEN", token);
            setToken(token);
            setCrossToken(data.authentication.access_token);
            resolve();
          }
        })
        .catch(error => {
          reject(error);
          console.log("登录错误", error);
        });
    });
  },
  // get 获取用户信息
  async getInfo({ commit, state }) {
    return new Promise(async (resolve, reject) => {
      try {
        await getInfo(state.token)
          .then(async response => {
            if (response.code == 200) {
              const data = response;
              if (!data.data) {
                reject("获取用户信息错误,请重新登录");
              }
              const username = data.data.realName || data.data.username;
              const avatar = data.data.avatar;
              const organ = data.data.organId;
              const organName = data.data.organName;
              const phone = data.data.phone;
              const isSuperAdmin = data.data.isSuperAdmin;
              const roles = data.data?.positions?.split(",") || [];
              const tenantId = data.data.tenantId;
              const positionName = data.data.positionName;
              const imToken = data.data.imToken;
              sessionStorage.setItem("baseTenantId", tenantId);
              commit("SET_BASETENANTID", tenantId);
              let tenantConfig = sessionStorage.getItem("tenantConfig");
              tenantConfig = tenantConfig ? JSON.parse(tenantConfig) : {};
              if (tenantConfig.tenantStatus != "on") {
                await tenantQueryPage(tenantId);
                // 会重置数据
                tenantConfig = sessionStorage.getItem("tenantConfig");
                tenantConfig = tenantConfig ? JSON.parse(tenantConfig) : {};
              }
              if (tenantId > 0) {
                // 判断是机构才会根据主题去设置
                const themeColor = tenantConfig.themeColor;
                const theme = tenantConfig.theme;
                setTheme({ theme, themeColor });
              }
              commit("SET_TENANTID", stateTenantId);
              commit("SET_NAME", username);
              commit("SET_AVATAR", avatar);
              commit("SET_ORGAN", organ);
              commit("SET_ORGANNAME", organName);
              commit("SET_PHONE", phone);
              commit("SET_SUPERADMIN", isSuperAdmin);
              commit("SET_ROLES", roles);
              commit("SET_POSITIONNAME", positionName);
              commit("SET_IMTOKEN", imToken);
              resolve(data);
            } else {
              reject("获取用户信息错误,请重新登录");
            }
          })
          .catch(error => {
            reject("获取用户信息错误,请重新登录");
          });
      } catch (e) {
        reject("获取用户信息错误,请重新登录");
      }
    });
  },
  // 登出
  logout({ commit }) {
    return new Promise((resolve, reject) => {
      logout()
        .then((res) => {
          console.log(res)
          commit("SET_TOKEN", "");
          removeToken();
          setToken("");
          removeCrossToken();
          resetRouter();
          removeTenant(); // 移除机构信息
          commit("SET_NAME", "");
          resolve();
        })
        .catch(error => {
          reject(error);
        });
    });
  },

  // remove token
  resetToken({ commit }) {
    return new Promise(resolve => {
      commit("SET_TOKEN", "");
      removeToken();
      removeCrossToken();
      removeTenant(); // 移除机构信息
      resolve();
      setToken("");
    });
  }
};

export default {
  namespaced: true,
  state,
  mutations,
  actions
};
